@@ -35,12 +35,10 @@
 
 #include <KMessageBox>
 #include "korganizer_debug.h"
-#include <KConfigGroup>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
 #include <kcolorscheme.h>
-#include <KHelpClient>
 
 FilterEditDialog::FilterEditDialog(QList<KCalCore::CalFilter *> *filters, QWidget *parent)
     : QDialog(parent)
@@ -107,8 +105,8 @@ FilterEdit::FilterEdit(QList<KCalCore::CalFilter *> *filters, QWidget *parent)
         i18nc("@info:whatsthis",
               "Press this button to remove the currently active filter."));
 
-    connect(mRulesList, SIGNAL(itemSelectionChanged()),
-            this, SLOT(filterSelected()));
+    connect(mRulesList, QOverload<>::of(&QListWidget::itemSelectionChanged),
+            this, QOverload<>::of(&FilterEdit::filterSelected));
 
     connect(mNewButton, &QPushButton::clicked, this, &FilterEdit::bNewPressed);
     connect(mDeleteButton, &QPushButton::clicked, this, &FilterEdit::bDeletePressed);
@@ -128,7 +126,7 @@ void FilterEdit::updateFilterList()
     mRulesList->clear();
     if (!mFilters || mFilters->empty()) {
         mDetailsFrame->setEnabled(false);
-        Q_EMIT(dataConsistent(false));
+        Q_EMIT dataConsistent(false);
     } else {
         QList<KCalCore::CalFilter *>::iterator i;
         QList<KCalCore::CalFilter *>::iterator end(mFilters->end());
@@ -143,7 +141,7 @@ void FilterEdit::updateFilterList()
                 filterSelected(f);
             }
         }
-        Q_EMIT(dataConsistent(true));
+        Q_EMIT dataConsistent(true);
     }
     if (mFilters && !mFilters->isEmpty() && !mCurrent) {
         filterSelected(mFilters->at(0));
@@ -313,7 +311,7 @@ bool FilterEdit::correctName(const QString &newText)
 #ifndef QT_NO_STYLE_STYLESHEET
     QString styleSheet;
     if (mNegativeBackground.isEmpty()) {
-        KStatefulBrush bgBrush = KStatefulBrush(KColorScheme::View, KColorScheme::NegativeBackground);
+        const KStatefulBrush bgBrush = KStatefulBrush(KColorScheme::View, KColorScheme::NegativeBackground);
         mNegativeBackground = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(mNameLineEdit).color().name());
     }
     if (!newText.isEmpty()) {
