@@ -43,7 +43,6 @@
 
 #include <KActionCollection>
 #include <KMime/Message>
-#include <KMimeTypeTrader>
 #include "korganizer_debug.h"
 
 #include <IncidenceEditor/IncidenceDialogFactory>
@@ -52,7 +51,6 @@
 KOEventPopupMenu::KOEventPopupMenu(Akonadi::ETMCalendar *calendar, QWidget *parent)
     : QMenu(parent), mCalendar(calendar)
 {
-    mHasAdditionalItems = false;
 
     addAction(QIcon::fromTheme(QStringLiteral("document-preview")), i18n("&Show"),
               this, &KOEventPopupMenu::popupShow);
@@ -83,8 +81,7 @@ KOEventPopupMenu::KOEventPopupMenu(Akonadi::ETMCalendar *calendar, QWidget *pare
                                     this, SLOT(popupDelete())));
     //------------------------------------------------------------------------
     addSeparator();
-    QAction *action;
-    action = addAction(QIcon::fromTheme(QStringLiteral("task-new")),
+    QAction *action = addAction(QIcon::fromTheme(QStringLiteral("task-new")),
                        i18n("Create To-do"),
                        this, SLOT(createTodo()));
     action->setObjectName(QStringLiteral("createtodo"));
@@ -142,7 +139,7 @@ void KOEventPopupMenu::showIncidencePopup(const Akonadi::Item &item, const QDate
     KCalCore::Incidence::Ptr incidence = CalendarSupport::incidence(mCurrentIncidence);
     Q_ASSERT(incidence);
     if (incidence->recurs()) {
-        const KDateTime thisDateTime(qd, CalendarSupport::KCalPrefs::instance()->timeSpec());
+        const QDateTime thisDateTime(qd, {}, Qt::LocalTime);
         const bool isLastOccurrence =
             !incidence->recurrence()->getNextDateTime(thisDateTime).isValid();
         const bool isFirstOccurrence =
